@@ -11,13 +11,14 @@ logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 
-secrat_key = get_secret_key()
+secret_key = get_secret_key()
 
 
 def check_signature(client_signature, data_message):
     # get the raw data and HMAC signature from client side..
-    server_hmac_signature = hash_function(secrat_key, data_message)
-    print(server_hmac_signature)
+    server_hmac_signature = hash_function(secret_key, data_message)
+    logger.info(data_message)
+    logger.info(server_hmac_signature)
     if(server_hmac_signature == client_signature):
         return True
     else:
